@@ -1,7 +1,7 @@
 
 use strict;
 use Tcl::Tk qw/:perlTk/;
-#BEGIN {$::Tcl::Tk::DEBUG=1}
+BEGIN {$::Tcl::Tk::DEBUG=3}
 
 my $mw = MainWindow->new;
 
@@ -13,7 +13,7 @@ my $w4 = $mw->Entry->pack;
 
 my $mmw = new Tcl::Tk::Widget::MultipleWidget (
    $mw->interp,
-   $w1, ['-labtext1=-text',''],
+   $w1, ['-labtext1=-text'],
    $w2, ['-labtext2=-text'],
    $w3, ['-labtext3=-text','&'],
    $w4, ['&get2=get'],
